# Release v0.5.0rc1

Date: 2026-01-07
Changes since 0.5.0rc

- 0.5.0rc release (1e8d4f7)
- docs: ignore MD041 in README for logo header (84584fb)
- docs: keep README first line as H1 (8657f48)
- docs: polish README with logo and links (057b924)
- release: stop auto-editing docs index (05a86c9)
